

function KQSettings_VariablesLoaded(self)
	-- set default prefs values if nothing stored
	if not KQ_SETTINGS.muteInFightMode then
		KQ_SETTINGS.muteInFightMode = {
			["SinglePlayer"] = true,
			["Party"] = true,
			["Raid"] = true,
			["Instance"] = true,
		}
	end
	if not KQ_SETTINGS.muteInFightChannelGroup then
		KQ_SETTINGS.muteInFightChannelGroup = {
			["Public"] = true,
			["Guild"] = true,
			["Raid"] = true,
		}
	end
	KQSettings_Localize()
	KQSettings_Update()
end

function KQSettings_OnEvent(self, event, ...)
	if event == "PLAYER_LOGIN" then
		loggedIn = true
		self:UnregisterEvent("PLAYER_LOGIN")
	end
	if event == "VARIABLES_LOADED" then
		variablesLoaded = true
		self:UnregisterEvent("VARIABLES_LOADED")
	end
	if variablesLoaded and loggedIn then
		KQSettings_VariablesLoaded(self)
	end
end

function KQSettings_OnLoad(self)
	-- KQ_Print("KQSettings_OnLoad")
	local settingsPanel = self
	KQSettings_Localize()
	settingsPanel.name = "KQuote"
	settingsPanel.okay = function (self) KQSettings_Okay(); end;
	settingsPanel.default = function (self) KQSettings_Default(); KQSettings_Update(); end;
	InterfaceOptions_AddCategory(settingsPanel)
end

function KQSettings_Localize()
	KQSettings_ChannelHeader:SetText(KQuoteSettings_Loc["ChannelHeader"])
	KQSettings_ChannelWhisperText:SetText(KQuoteSettings_Loc["ChannelWhisper"])
	KQSettings_ChannelSayText:SetText(KQuoteSettings_Loc["ChannelSay"])
	KQSettings_ChannelYellText:SetText(KQuoteSettings_Loc["ChannelYell"])
	KQSettings_ChannelPartyText:SetText(KQuoteSettings_Loc["ChannelParty"])
	KQSettings_ChannelRaidText:SetText(KQuoteSettings_Loc["ChannelRaid"])
	KQSettings_ChannelInstanceText:SetText(KQuoteSettings_Loc["ChannelInstance"])
	KQSettings_ChannelGuildText:SetText(KQuoteSettings_Loc["ChannelGuild"])
	KQSettings_ChannelOfficerText:SetText(KQuoteSettings_Loc["ChannelOfficer"])

	KQSettings_MuteInFightHeader:SetText(KQuoteSettings_Loc["MuteInFightHeader"])
	KQSettings_MuteSinglePlayerText:SetText(KQuoteSettings_Loc["MuteSinglePlayer"])
	KQSettings_MutePartyText:SetText(KQuoteSettings_Loc["MuteParty"])
	KQSettings_MuteRaidText:SetText(KQuoteSettings_Loc["MuteRaid"])
	KQSettings_MuteInstanceText:SetText(KQuoteSettings_Loc["MuteInstance"])

	KQSettings_MuteChannelsHeader:SetText(KQuoteSettings_Loc["MuteChannelsHeader"])
	KQSettings_MuteChannelGroup1Text:SetText(KQuoteSettings_Loc["MuteChannelGroup1"])
	KQSettings_MuteChannelGroup2Text:SetText(KQuoteSettings_Loc["MuteChannelGroup2"])
	KQSettings_MuteChannelGroup3Text:SetText(KQuoteSettings_Loc["MuteChannelGroup3"])
	KQSettings_MuteChannelGroup3Label2:SetText(KQuoteSettings_Loc["MuteChannelGroup3Label2"])
end

function KQSettings_Update()
	-- KQ_Print("KQSettings_Update")
	KQSettings_ChannelWhisper:SetChecked(KQ_SETTINGS.broadcast["CHAT_MSG_WHISPER"])
	KQSettings_ChannelSay:SetChecked(KQ_SETTINGS.broadcast["CHAT_MSG_SAY"])
	KQSettings_ChannelYell:SetChecked(KQ_SETTINGS.broadcast["CHAT_MSG_YELL"])
	KQSettings_ChannelParty:SetChecked(KQ_SETTINGS.broadcast["CHAT_MSG_PARTY"])
	KQSettings_ChannelRaid:SetChecked(KQ_SETTINGS.broadcast["CHAT_MSG_RAID"])
	KQSettings_ChannelInstance:SetChecked(KQ_SETTINGS.broadcast["CHAT_MSG_INSTANCE_CHAT"])
	KQSettings_ChannelGuild:SetChecked(KQ_SETTINGS.broadcast["CHAT_MSG_GUILD"])
	KQSettings_ChannelOfficer:SetChecked(KQ_SETTINGS.broadcast["CHAT_MSG_OFFICER"])

	KQSettings_MuteSinglePlayer:SetChecked(KQ_SETTINGS.muteInFightMode["SinglePlayer"])
	KQSettings_MuteParty:SetChecked(KQ_SETTINGS.muteInFightMode["Party"])
	KQSettings_MuteRaid:SetChecked(KQ_SETTINGS.muteInFightMode["Raid"])
	KQSettings_MuteInstance:SetChecked(KQ_SETTINGS.muteInFightMode["Instance"])

	KQSettings_MuteChannelGroup1:SetChecked(KQ_SETTINGS.muteInFightChannelGroup["Guild"])
	KQSettings_MuteChannelGroup2:SetChecked(KQ_SETTINGS.muteInFightChannelGroup["Public"])
	KQSettings_MuteChannelGroup3:SetChecked(KQ_SETTINGS.muteInFightChannelGroup["Raid"])
end

function KQSettings_Okay()
	-- KQ_Print("KQSettings_Okay")
	local checked = KQ_IsChecked(KQSettings_ChannelWhisper)
	KQ_SETTINGS.broadcast["CHAT_MSG_WHISPER"] = checked
	-- KQ_Print_Bool("whisper: ", KQ_SETTINGS.broadcast["CHAT_MSG_WHISPER"])
	checked = KQ_IsChecked(KQSettings_ChannelSay)
	KQ_SETTINGS.broadcast["CHAT_MSG_SAY"] = checked
	-- KQ_Print_Bool("say: ", KQ_SETTINGS.broadcast["CHAT_MSG_SAY"])
	checked = KQ_IsChecked(KQSettings_ChannelYell)
	KQ_SETTINGS.broadcast["CHAT_MSG_YELL"] = checked
	-- KQ_Print_Bool("yell: ", KQ_SETTINGS.broadcast["CHAT_MSG_YELL"])
	checked = KQ_IsChecked(KQSettings_ChannelParty)
	KQ_SETTINGS.broadcast["CHAT_MSG_PARTY"] = checked
	KQ_SETTINGS.broadcast["CHAT_MSG_PARTY_LEADER"] = checked
	-- KQ_Print_Bool("party: ", KQ_SETTINGS.broadcast["CHAT_MSG_PARTY"])
	checked = KQ_IsChecked(KQSettings_ChannelRaid)
	KQ_SETTINGS.broadcast["CHAT_MSG_RAID"] = checked
	KQ_SETTINGS.broadcast["CHAT_MSG_RAID_LEADER"] = checked
	-- KQ_Print_Bool("raid: ", KQ_SETTINGS.broadcast["CHAT_MSG_RAID"])
	checked = KQ_IsChecked(KQSettings_ChannelInstance)
	KQ_SETTINGS.broadcast["CHAT_MSG_INSTANCE_CHAT"] = checked
	KQ_SETTINGS.broadcast["CHAT_MSG_INSTANCE_CHAT_LEADER"] = checked
	-- KQ_Print_Bool("instance: ", KQ_SETTINGS.broadcast["CHAT_MSG_INSTANCE_CHAT"])
	checked = KQ_IsChecked(KQSettings_ChannelGuild)
	KQ_SETTINGS.broadcast["CHAT_MSG_GUILD"] = checked
	-- KQ_Print_Bool("guild: ", KQ_SETTINGS.broadcast["CHAT_MSG_GUILD"])
	checked = KQ_IsChecked(KQSettings_ChannelOfficer)
	KQ_SETTINGS.broadcast["CHAT_MSG_OFFICER"] = checked
	-- KQ_Print_Bool("officer: ", KQ_SETTINGS.broadcast["CHAT_MSG_OFFICER"])

	checked = KQ_IsChecked(KQSettings_MuteSinglePlayer)
	KQ_SETTINGS.muteInFightMode["SinglePlayer"] = checked
	checked = KQ_IsChecked(KQSettings_MuteParty)
	KQ_SETTINGS.muteInFightMode["Party"] = checked
	checked = KQ_IsChecked(KQSettings_MuteRaid)
	KQ_SETTINGS.muteInFightMode["Raid"] = checked
	checked = KQ_IsChecked(KQSettings_MuteInstance)
	KQ_SETTINGS.muteInFightMode["Instance"] = checked

	checked = KQ_IsChecked(KQSettings_MuteChannelGroup1)
	KQ_SETTINGS.muteInFightChannelGroup["Guild"] = checked
	checked = KQ_IsChecked(KQSettings_MuteChannelGroup2)
	KQ_SETTINGS.muteInFightChannelGroup["Public"] = checked
	checked = KQ_IsChecked(KQSettings_MuteChannelGroup3)
	KQ_SETTINGS.muteInFightChannelGroup["Raid"] = checked
end

function KQSettings_Default()
	KQ_SETTINGS.broadcast["CHAT_MSG_WHISPER"] = false
	KQ_SETTINGS.broadcast["CHAT_MSG_SAY"] = true
	KQ_SETTINGS.broadcast["CHAT_MSG_YELL"] = false
	KQ_SETTINGS.broadcast["CHAT_MSG_PARTY"] = true
	KQ_SETTINGS.broadcast["CHAT_MSG_PARTY_LEADER"] = true
	KQ_SETTINGS.broadcast["CHAT_MSG_RAID"] = true
	KQ_SETTINGS.broadcast["CHAT_MSG_RAID_LEADER"] = true
	KQ_SETTINGS.broadcast["CHAT_MSG_INSTANCE_CHAT"] = true
	KQ_SETTINGS.broadcast["CHAT_MSG_INSTANCE_CHAT_LEADER"] = true
	KQ_SETTINGS.broadcast["CHAT_MSG_GUILD"] = true
	KQ_SETTINGS.broadcast["CHAT_MSG_OFFICER"] = true

	KQ_SETTINGS.muteInFightMode["SinglePlayer"] = false
	KQ_SETTINGS.muteInFightMode["Party"] = false
	KQ_SETTINGS.muteInFightMode["Raid"] = false
	KQ_SETTINGS.muteInFightMode["Instance"] = false

	KQ_SETTINGS.muteInFightChannelGroup["Public"] = true
	KQ_SETTINGS.muteInFightChannelGroup["Guild"] = true
	KQ_SETTINGS.muteInFightChannelGroup["Raid"] = false
end
