
BINDING_HEADER_KQUOTE_HEADER = "KQuote"
BINDING_NAME_KQUOTE_TOGGLE = "Toggle KQuote"


KQUI = {
	NUM_DISPLAYABLE = 20,	-- maxmimum number of quotes that are visible at a time
	
	CategoryDropDown = {},	-- hold functions for the Category DropDown
	ChannelDropDown = {},	-- hold functions for the Channel DropDown
	TotalItemCount = -1,		-- number of all available quotes
	DisplayedItems = {},	-- all quotes displayed for the current category
	
	Quote = KQ_Say,			-- the quote function that is used for posting quotes
	Channels = {
		{ name=KQChannels.w.name, func=KQ_Whisper },
		{ name=KQChannels.s.name, func=KQ_Say },
		{ name=KQChannels.y.name, func=KQ_Yell },
		{ name=KQChannels.p.name, func=KQ_PartyRaidOrInstance },
		{ name=KQChannels.g.name, func=KQ_Guild },
		{ name=KQChannels.o.name, func=KQ_Officer },
		{ name=KQChannels.t.name, func=KQ_Test },
	},
	
	Sorters = {
		ByMessage = function(a, b) return (a.msg < b.msg) end,
		ByID = function(a, b) return (a.id < b.id) end
	},
	Sorter = function(a, b) return (a.msg < b.msg) end,
	
	CurrentTag = ".",
	CurrentSearchText = "",	-- current search text
	EditMode = false,
}

local variablesLoaded = false
local loggedIn = false



function KQUI:Msg(msg)
	DEFAULT_CHAT_FRAME:AddMessage(msg, 1.0, 0.5, 0.5)
end

function KQUI:Toggle()
	if self:IsVisible() then
		HideUIPanel(self)
	else
		ShowUIPanel(self)
	end
end

function KQUI:InsertSearchText(text)
	local searchField = _G[self:GetName().."SearchText"]
	searchField:SetText(text)
	if text ~= "" then
		searchField:HighlightText()
	end
	KQUI.CurrentSearchText = string.lower(text)
end

function KQUI:SelectTag(tag)
	UIDropDownMenu_SetSelectedValue(KQuoteDialogCategoryDropDown, tag)
	if tag == "." then
		UIDropDownMenu_SetText(KQuoteDialogCategoryDropDown, ALL)
	else
		UIDropDownMenu_SetText(KQuoteDialogCategoryDropDown, KQ_Tags[tag])
	end
	KQUI.CurrentTag = tag
end

function KQUI:ShowWindow(arg, selectTag)
	if (not self:IsVisible()) then
		ShowUIPanel(self)
	end
	if arg then
		if selectTag then
			KQUI:SelectTag(arg)
			KQUI:InsertSearchText("")
		else
			KQUI:InsertSearchText(arg)
			KQUI:SelectTag(".")
		end
		KQUI:FilterItems()
	end
end

function KQUI:Localize()
	local L = KQuoteUI_Localization
	local name = self:GetName()
	
	_G[name.."Title"]:SetText(L.DIALOG_TITLE..KQ_VERSION)

	_G[name.."ColumnText"]:SetText(L.COLUMN_TEXT)
	_G[name.."ColumnID"]:SetText(L.COLUMN_DURATION)
	_G[name.."MuteCheckboxText"]:SetText(L.CHECKBOX_MUTE)
	_G[name.."MuteCheckboxText"]:SetPoint("TOPLEFT", self, "TOPLEFT", 156, -76)
	_G[name.."MuteCheckbox"]:SetHitRectInsets(0, -30, 0, 0)
	
	BINDING_HEADER_KQUOTE_HEADER = L.BINDING_HEADER
	BINDING_NAME_KQUOTE_TOGGLE = L.BINDING_TOGGLE
	BINDING_NAME_KQUOTE_MUTE = L.BINDING_MUTE
end

function KQUI:Initialize()

	UIPanelWindows[self:GetName()] = { area = "left", pushable = 5, whileDead = 1 }

	self:Localize()	
	self.QuoteEntries = {}
	
	-- create list items
	self.QuoteEntries[1] = CreateFrame("Button", "KQuoteItem1", self, "KQuoteItemTemplate2")
	self.QuoteEntries[1]:SetPoint("TOPLEFT", self, "TOPLEFT", 20, -100)

	for i=2, self.NUM_DISPLAYABLE do
		self.QuoteEntries[i] = CreateFrame("Button", "KQuoteItem"..i, self, "KQuoteItemTemplate2")
		self.QuoteEntries[i]:SetPoint("TOPLEFT", self.QuoteEntries[i-1], "BOTTOMLEFT", 0, 0)
--		self.QuoteEntries[i]:SetPoint("TOPLEFT", self.QuoteEntries[i-1], "BOTTOMLEFT", 0, 0)
	end
	KQUI:HideCheckmarks(true)
end

function KQUI:HideCheckmarks(hide)
	for i=1, self.NUM_DISPLAYABLE do
		local button = self.QuoteEntries[i]

		local buttonName = button:GetName()
		
		if hide then
			_G[buttonName.."Enabled"]:Hide()
			_G[buttonName.."LabelsText"]:SetPoint("TOPLEFT", button, "TOPLEFT", 5, 0)
			_G[buttonName.."LabelsText"]:SetSize(235, 0)
		else
			_G[buttonName.."LabelsText"]:SetPoint("TOPLEFT", button, "TOPLEFT", 25, 0)
			_G[buttonName.."LabelsText"]:SetSize(215, 0)
			_G[buttonName.."Enabled"]:Show()
		end
	end
end

function KQUI:CountItems()
	local allModules = KQ_ModuleData()
	if KQUI.TotalItemCount < 0 then
		KQUI.TotalItemCount = 0
		for moduleid, module in pairs(allModules) do
			KQUI.TotalItemCount = KQUI.TotalItemCount + #module.mediadata
		end -- for module
		if KQUI.TotalItemCount == 0 then
			-- insert info dialog about media packages
			self.KQuoteMediaPackagesInfo = CreateFrame("Frame", "KQuoteMediaPackagesInfo", self, "KQuoteMediaPackagesInfoTemplate")
			KQuoteMediaPackagesInfoTitle:SetPoint("TOPLEFT", self, "TOPLEFT", 30, -120)
			KQuoteMediaPackagesInfoTitle:SetText(KQuoteUI_Localization.MEDIA_PACKAGES_INFO_TITLE)
			KQuoteMediaPackagesInfoText1:SetPoint("TOPLEFT", KQuoteMediaPackagesInfoTitle, "BOTTOMLEFT", 0, -30)
			KQuoteMediaPackagesInfoText1:SetText(KQuoteUI_Localization.MEDIA_PACKAGES_INFO_TEXT1)
			KQuoteMediaPackagesInfoLink:SetPoint("TOPLEFT", KQuoteMediaPackagesInfoText1, "BOTTOMLEFT", 0, -10)
			KQuoteMediaPackagesInfoLink:SetText(KQuoteUI_Localization.MEDIA_PACKAGES_INFO_LINK)
			KQuoteMediaPackagesInfoText2:SetPoint("TOPLEFT", KQuoteMediaPackagesInfoLink, "BOTTOMLEFT", 0, -10)
			KQuoteMediaPackagesInfoText2:SetText(KQuoteUI_Localization.MEDIA_PACKAGES_INFO_TEXT2)
		end
	end
end

function KQUI:DialogShow()
	KQUI:CountItems()
	KQUI:UpdateMuteCheckbox()
	local searchField = _G[self:GetName().."SearchText"]
	searchField:SetFocus()
	KQUI:FilterItems()
end

function KQUI:UpdateMuteCheckbox()
	local muteCheckbox = _G[self:GetName().."MuteCheckbox"]
	muteCheckbox:SetChecked(KQ_SETTINGS.mute)
end

function KQUI:SetEditMode(doEdit)
	KQUI.EditMode = doEdit
	KQUI:HideCheckmarks(not doEdit)
	KQUI:FilterItems()
end

function KQUI:UpdateItems()
	local numItems = #self.DisplayedItems
	local scrollFrame = _G[self:GetName().."ScrollFrame"]
	local offset = math.max(0, math.min(FauxScrollFrame_GetOffset(scrollFrame), numItems-self.NUM_DISPLAYABLE))
	
	if #self.QuoteEntries > 0 then
		-- display quotes according to the scrollbar's offset
		for i=1, self.NUM_DISPLAYABLE do
			local button = self.QuoteEntries[i]
	
			if i <= numItems then
				local media = self.DisplayedItems[i+offset]
				local buttonName = button:GetName()
				
				_G[buttonName.."Enabled"]:SetChecked(not KQ_SETTINGS.disabled[media.id])
				_G[buttonName.."LabelsText"]:SetText(media.msg)
				_G[buttonName.."LabelsID"]:SetText(media.id)
				button.id = media.id
				button:Show()
			else -- hide unused button if there are less quotes than buttons
				button:Hide()
			end			
		end
	end

	FauxScrollFrame_Update(scrollFrame, numItems, self.NUM_DISPLAYABLE, 16)
end

function KQUI:SortItems(...)
	local arg = {...}

	if arg[1] then
		self.Sorter = arg[1]
	end
	sort(KQUI.DisplayedItems, self.Sorter)
end

function KQUI:FilterItems()
	KQUI.DisplayedItems = {}
	local allModules = KQ_ModuleData()
	for moduleid, module in pairs(allModules) do
		for quoteid, quote in pairs(module.mediadata) do
			local match = KQUI.EditMode or not KQ_SETTINGS.disabled[quote.id]
			if ((KQUI.CurrentTag == ".") or KQ_QuoteHasTag(quote, KQUI.CurrentTag)) then
				if KQUI.CurrentSearchText ~= "" then
					match = ((string.find(string.lower(quote.msg), KQUI.CurrentSearchText)) ~= nil)
				end
			else
				match = false
			end
			if match then
				table.insert(KQUI.DisplayedItems, quote)
			end
		end -- for quote
	end -- for module
	
	self:SortItems()	
	self:UpdateItems()
end

function KQUI:SetSearchText()
	local searchField = _G[self:GetName().."SearchText"]
	KQUI.CurrentSearchText = string.lower(searchField:GetText())
	KQUI:FilterItems()
end

function KQUI:SearchButton_OnUpdate(self, event, ...)
	local searchField = _G[self:GetName().."SearchText"]
	if searchField:GetText() == KQUI.CurrentSearchText	then
		self:Disable()
	else
		self:Enable()
	end
end

function KQUI.CategoryDropDown.OnClick(self, event, ...)
	local tag = self.value
	UIDropDownMenu_SetSelectedValue(KQuoteDialogCategoryDropDown, tag)
	KQUI.CurrentTag = tag
	KQUI:FilterItems()
end

function KQUI.CategoryDropDown.Initialize()
	UIDropDownMenu_AddButton({text=ALL, value=".", func=KQUI.CategoryDropDown.OnClick})
	
	-- since dictionaries do not have an inherent order, we need to create an indexed list
	local list = {}
	for key, value in pairs(KQ_Tags) do
		table.insert(list, {key, value})
	end	
	table.sort(list, function(a, b) return a[2] < b[2] end)
	for i, item in ipairs(list) do
		local key = item[1]
		local value = item[2]
		UIDropDownMenu_AddButton({text=value, value=key, func=KQUI.CategoryDropDown.OnClick})
	end
end

function KQUI.ChannelDropDown.OnClick(self, event, ...)
	local channel = self:GetID()
	UIDropDownMenu_SetSelectedID(KQuoteDialogChannelDropDown, channel)
	
	KQUI.Quote = KQUI.Channels[channel].func
	KQUI:SetEditMode(false)
end

function KQUI.ChannelDropDown.ToggleEdit(self, event, ...)
	local channel = self:GetID()
	UIDropDownMenu_SetSelectedID(KQuoteDialogChannelDropDown, channel)
	
	KQUI.Quote = KQ_Test
	KQUI:SetEditMode(true)
end

function KQUI.ChannelDropDown.Initialize()
	for i=1, #KQUI.Channels do
		UIDropDownMenu_AddButton({text=KQUI.Channels[i].name, func=KQUI.ChannelDropDown.OnClick})
	end
	UIDropDownMenu_AddButton({text=KQuoteUI_Localization.CHANNEL_DROPDOWN_DIVIDER, notClickable=true, notCheckable=true, justifyH="CENTER"})
	UIDropDownMenu_AddButton({text=KQuoteUI_Localization.CHANNEL_DROPDOWN_LABEL_EDIT, func=KQUI.ChannelDropDown.ToggleEdit})
end

function KQUI:SetMute(self, button, down)
	local muteCheckbox = _G[self:GetName()]
	KQ_SETTINGS.mute = KQ_IsChecked(muteCheckbox)
end

function KQUI.ToggleEnabled(self, quoteid)
	local checkbox = _G[self:GetName()]
	if KQ_IsChecked(checkbox) then
		KQ_SETTINGS.disabled[quoteid] = nil
	else
		KQ_SETTINGS.disabled[quoteid] = true
	end
end

